Button

Struct Button 

pub struct Button { /* private fields */ }
Simply a button.

Normal

fn app() -> impl IntoElement {
    Button::new()
        .on_press(|_| println!("Pressed!"))
        .child("Press me")
}

Filled

fn app() -> impl IntoElement {
    Button::new()
        .on_press(|_| println!("Pressed!"))
        .filled()
        .child("Press me")
}

Outline

fn app() -> impl IntoElement {
    Button::new()
        .on_press(|_| println!("Pressed!"))
        .outline()
        .child("Press me")
}

Flat

fn app() -> impl IntoElement {
    Button::new()
        .on_press(|_| println!("Pressed!"))
        .flat()
        .child("Press me")
}

Preview

Button Preview Outline Button Preview Filled Button Preview Flat Button Preview

Implementations

Source

impl Button

pub fn new() -> Self

pub fn get_layout_variant(&self) -> &ButtonLayoutVariant

pub fn get_theme_layout(&self) -> Option<&ButtonLayoutThemePartial>

pub fn enabled(self, enabled: impl Into<bool>) -> Self

pub fn focusable(self, focusable: impl Into<bool>) -> Self

pub fn style_variant(self, style_variant: impl Into<ButtonStyleVariant>) -> Self

pub fn layout_variant( self, layout_variant: impl Into<ButtonLayoutVariant>, ) -> Self

pub fn on_press( self, on_press: impl Into<EventHandler<Event<PressEventData>>>, ) -> Self

pub fn on_secondary_down( self, on_secondary_down: impl Into<EventHandler<Event<PressEventData>>>, ) -> Self

pub fn on_pointer_down( self, on_pointer_down: impl Into<EventHandler<Event<PointerEventData>>>, ) -> Self

pub fn theme_colors(self, theme: ButtonColorsThemePartial) -> Self

pub fn theme_layout(self, theme: ButtonLayoutThemePartial) -> Self

pub fn compact(self) -> Self

pub fn expanded(self) -> Self

pub fn filled(self) -> Self

pub fn outline(self) -> Self

pub fn flat(self) -> Self

pub fn cursor_icon(self, cursor_icon: impl Into<CursorIcon>) -> Self

Override the cursor icon shown when hovering over the button while enabled.