ColorPicker

Struct ColorPicker 

pub struct ColorPicker { /* private fields */ }
HSV-based gradient color picker.

Example

fn app() -> impl IntoElement {
    let mut color = use_state(|| Color::from_hsv(0.0, 1.0, 1.0));
    rect()
        .padding(6.)
        .child(ColorPicker::new(move |c| color.set(c)).value(color()))
}

Preview

ColorPicker Preview

The preview image is generated by simulating a click on the preview so the popup is shown. This is done using the with_hook helper in the doc test to move the cursor and click the preview.

Implementations

Source

impl ColorPicker

pub fn new(on_change: impl Into<EventHandler<Color>>) -> Self

pub fn value(self, value: Color) -> Self

pub fn width(self, width: impl Into<Size>) -> Self