Slider

Struct Slider 

pub struct Slider { /* private fields */ }
Slider component.

You must pass a percentage from 0.0 to 100.0 and listen for value changes with on_moved and then decide if this changes are applicable, and if so, apply them.

Example

fn app() -> impl IntoElement {
    let mut percentage = use_state(|| 25.0);

    Slider::new(move |per| percentage.set(per)).value(percentage())
}

Preview

Slider Preview

Implementations

Source

impl Slider

pub fn new(on_moved: impl Into<EventHandler<f64>>) -> Self

pub fn enabled(self, enabled: impl Into<bool>) -> Self

pub fn value(self, value: f64) -> Self

pub fn theme(self, theme: SliderThemePartial) -> Self

pub fn size(self, size: Size) -> Self

pub fn direction(self, direction: Direction) -> Self

pub fn cursor_icon(self, cursor_icon: impl Into<CursorIcon>) -> Self

Override the cursor icon shown when hovering over this component while enabled.